/* *****************************************

              *** README ***

****************************************** */
.header {

  /* 헤더 높이 */
  --header-height: 65px;

  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  z-index: 9999;
  color: #ffffff;
  background-color: rgba(14, 0, 61, .2);
  transition: background-color 0.3s ease, border-color 0.3s ease;
}

.header .inner {
  display: flex;
  justify-content: space-between;
  align-items: center;
  gap: 20px;
  height: var(--header-height);
}

/* header-logo */
.header-logo {
  width: 150px;
}

.header-logo a {
  position: relative;
  z-index: 100;
  display: flex;
  align-items: center;
}

.header-logo img {
  height: 25px;
}

.header-btn {
  width: 150px;
  display: flex;
  justify-content: end;
  gap: 14px;
}

/* header__btn__global */
.header-global {
  --global-width: 65px;
  width: var(--global-width);
  cursor: pointer;
  position: relative;
  font-size: .875rem;
}

.header-global__wrap {
  width: var(--global-width);
  position: absolute;
  left: 50%;
  top: -3px;
  transform: translateX(-50%);
  transition: all .3s;
  height: 24px;
  padding-top: 2px;
  padding-right: 4px;
  border-radius: 14px;
  border: 1px solid #fff;
}

.header-global__current {
  display: flex;
  justify-content: center;
  align-items: center;
  gap: 8px;
  color: inherit;
  position: relative;
}

.header-global__current::after {
  content: '>';
  position: absolute;
  right: 6px;
  font-size: .5rem;
  transform: rotate(90deg) translateX(1px);
  transition: all .3s;
}

.header-global:hover .header-global__current::after {
  transform: rotate(-90deg) translateX(1px);
}

.header-global__expand {
  width: var(--global-width);
  margin-top: 6px;
  padding-right: 6px;

  opacity: 0;
  visibility: hidden;

  transition:
    opacity 0.15s ease,
    transform 0.15s ease,
    visibility 0.15s ease;
}

.header-global__expand a {
  display: flex;
  justify-content: center;
  align-items: center;
  gap: 8px;
}

.header-global:hover .header-global__wrap {
  height: 50px;
  background-color: #ffffff;
  color: #000000 !important;
}

.header-global:hover .header-global__expand {
  opacity: 1;
  visibility: visible;
}

/* header-menu */
.header-menu {
  display: flex;
  justify-content: center;
  align-items: center;
}

.header-menu__open {
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  width: 24px;
  height: 16px;
  cursor: pointer;
  position: relative;
  z-index: 100;
}

.header-menu__open .bar {
  display: block;
  width: 100%;
  height: 2px;
  background-color: #ffffff;
  transition: 0.3s ease;
  transform-origin: center center;
}

/* header__nav */
.header__nav {
  flex: 1;
}

/* 대메뉴 */
.header__gnb {
  display: flex;
  justify-content: center;
  align-items: center;
  gap: 60px;
  height: var(--header-height);

  font-size: 1.05rem;
  font-weight: 600;
  text-transform: uppercase;
}

/* 서브메뉴 */
.header__sub {
  position: absolute;
  top: 100%;
  left: 0;
  top: var(--header-height);
  width: 100%;
  height: 200px;
  background: #ffffff;
  color: #000000;

  font-size: 1rem;
  font-weight: 400;
}

.header__sub__wrap {
  position: relative;
  width: 100%;
  height: 100%;
}

.header__sub__list {
  position: absolute;
  top: 0;
  height: 100%;
  text-align: left;
  padding-top: 16px;
}

.header__sub__list li {
  padding: 8px 0;
}

/* sitemap__wrap */
.sitemap__wrap {
  --color--smpoint: #e67e22;
  --color--smbg: #0a0a0a;

  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100vh;
  background: var(--color--smbg);
  color: #fff;
  z-index: 99;
  overflow-y: auto;
  overflow-x: hidden;
  font-family: 'Pretendard', -apple-system, BlinkMacSystemFont, system-ui, sans-serif;
  -webkit-font-smoothing: antialiased;
}

.sitemap__box {
  position: relative;
  width: 100%;
  min-height: 100vh;
  display: flex;
  align-items: center;
  padding: 80px 8vw;
  box-sizing: border-box;
  overflow: hidden;
}

.sitemap__deco {
  position: absolute;
  left: -50px;
  bottom: -50px;
  width: 600px;
  opacity: .1;
  pointer-events: none;
  z-index: 0;
}

.sitemap {
  width: 100%;
  max-width: 1400px;
  margin: 0 auto;
  position: relative;
  z-index: 1;
}

.sitemap__list {
  display: grid;
  grid-template-columns: repeat(4, 1fr);
  gap: 80px 40px;
  list-style: none;
  padding: 0;
  margin: 0;
}

.sitemap__list > li {
  position: relative;
  counter-increment: sitemap-counter;
}

.sitemap__list > li::before {
  content: "0" counter(sitemap-counter);
  display: block;
  font-family: 'Playfair Display', serif;
  font-size: 1rem;
  color: var(--color--smpoint);
  margin-bottom: 25px;
  letter-spacing: 0.2em;
  font-weight: 600;
}

.sitemap__list > li > a {
  display: inline-block;
  font-size: 1.8rem;
  font-weight: 700;
  color: #ffffff;
  text-decoration: none;
  letter-spacing: -0.02em;
  margin-bottom: 35px;
  transition: all 0.3s ease;
}

.sitemap__list > li > a::after {
  content: '';
  display: block;
  width: 40px;
  height: 2px;
  background: var(--color--smpoint);
  margin-top: 12px;
  transition: width 0.4s cubic-bezier(0.23, 1, 0.32, 1);
}

.sitemap__list > li:hover > a {
  color: var(--color--smpoint);
}

.sitemap__list > li:hover > a::after {
  width: 100%;
}

.sitemap__sublist {
  list-style: none;
  padding: 0;
  margin: 0;
}

.sitemap__sublist li {
  margin-bottom: 16px;
}

.sitemap__sublist li a {
  font-size: 1.1rem;
  color: #aaa;
  text-decoration: none;
  font-weight: 400;
  transition: all 0.3s;
  display: inline-block;
}

.sitemap__sublist li a:hover {
  color: #fff;
  padding-left: 10px;
}

@media (max-width: 1200px) {
  .sitemap__list {
    grid-template-columns: repeat(2, 1fr);
    gap: 60px 40px;
  }
}

@media (max-width: 768px) {
  .sitemap__box {
    align-items: flex-start;
    padding: 100px 40px;
  }

  .sitemap__deco {
    display: none;
  }

  .sitemap__list {
    grid-template-columns: 1fr;
    gap: 0;
    padding: 0;
  }

  .sitemap__list > li {
    border-bottom: none !important;
    padding: 15px 0;
    transition: padding 0.4s cubic-bezier(0.4, 0, 0.2, 1);
  }

  .sitemap__list > li::before {
    margin-bottom: 6px;
    font-size: 0.75rem;
    opacity: 0.8;
  }

  .sitemap__list > li > a {
    display: inline-block;
    font-size: 1.6rem;
    font-weight: 700;
    color: #fff;
    margin-bottom: 0;
    line-height: 1.1;
    transition: color 0.3s ease;
  }

  .sitemap__list > li > a::after {
    content: '';
    display: block;
    width: 40px;
    height: 2px;
    background: var(--color--smpoint);
    margin-top: 10px;
    /* 대메뉴 글자와 선 사이 간격 미세 단축 */
    transition: width 0.8s cubic-bezier(0.23, 1, 0.32, 1);
  }

  .sitemap__sublist {
    max-height: 0;
    opacity: 0;
    visibility: hidden;
    overflow: hidden;
    margin-top: 0;
    /* 닫혔을 때는 여백 없음 */
    padding-left: 2px;
    /* 닫힐 때는 0.4s */
    transition: max-height 0.4s cubic-bezier(0.4, 0, 0.2, 1),
      opacity 0.3s ease;
  }

  .sitemap__list > li.is-open {
    padding-top: 20px;
    /* 열릴 때 상단 여백 살짝 부여 */
    padding-bottom: 8px;
    /* 다음 대메뉴와 멀어지지 않게 최소화 */
  }

  .sitemap__list > li.is-open > a {
    color: var(--color--smpoint);
  }

  .sitemap__list > li.is-open .sitemap__sublist {
    max-height: 500px;
    opacity: 1;
    visibility: visible;
    /* 대메뉴 밑선과 서브메뉴 사이의 간격을 대폭 좁힘 */
    margin-top: 12px;
    padding-bottom: 12px;
    /* 서브메뉴 끝과 다음 대메뉴 사이의 여백 */
    /* 열릴 때 속도: 1.1s */
    transition: max-height 1.1s cubic-bezier(0.4, 0, 0.2, 1),
      opacity 0.8s ease 0.1s;
  }

  .sitemap__sublist li {
    margin-bottom: 10px;
  }

  .sitemap__sublist li:last-child {
    margin-bottom: 0;
  }

  .sitemap__sublist li a {
    font-size: 1.1rem;
    color: #bbb;
    font-weight: 400;
    transition: all 0.3s;
  }
}

body.no-scroll {
  overflow: hidden !important;
  touch-action: none;
}

.sitemap__wrap {
  touch-action: auto !important;
}

/* *****************************************

              *** Active ***
    hover, scroll 에 따른 header 변경 요소

****************************************** */

.header.hovered,
.header.scrolled {
  background-color: #000000;
}

.header.hovered .header__gnb,
.header.scrolled .header__gnb,
.header.hovered .header__btn,
.header.scrolled .header__btn {
  color: #fff;
}

.header.hovered .header-menu__open .bar,
.header.scrolled .header-menu__open .bar {
  background-color: #ffffff;
}

/* active 시 (열릴 때) → 햄버거가 X 로 변형 */
.header-menu__open.active .bar:nth-child(1) {
  transform: translateY(7px) rotate(45deg);
}

.header-menu__open.active .bar:nth-child(2) {
  opacity: 0;
}

.header-menu__open.active .bar:nth-child(3) {
  transform: translateY(-7px) rotate(-45deg);
}

/* active(X) 여도 흰색 고정 */
.header-menu__open.active .bar {
  background-color: #ffffff !important;
}

/* *****************************************

              *** media ***
        브레이크 포인트 반응형 제어   

****************************************** */

@media screen and (max-width: 1440px) {
  .header-logo {
    width: 200px;
  }
}

@media screen and (max-width:1280px) {

  .header__btn__global {
    width: 150px;
  }

  /* header__btn__global */
  .header__btn__global svg {
    width: 18px;
  }

  .header__btn__global span {
    font-size: 1rem;
  }

  .header__btn__global__box {
    top: -18px;
  }

  .header__btn__global__expand .img {
    width: 18px;
    height: 18px;
    border-radius: 50%;
    overflow: hidden;
  }

  .header__btn__global:hover .header__btn__global__box {
    height: 70px;
  }

  /* 대메뉴 */
  .header__gnb {
    font-size: 1rem;
  }

  /* 서브메뉴 */
  .header__sub {
    font-size: 1rem;
  }
}

@media screen and (max-width:1024px) {
  .header {
    /* 헤더 높이 */
    --header-height: 80px;
  }

  .header__btn__global {
    flex: 1;
  }

  /* header-logo */
  .header-logo {
    padding-left: 36px;
  }

  .header-logo img {
    height: 56px;
  }

  /* header__btn__global */
  .header__btn__global__box {
    left: auto;
    right: 0;
    transform: translateX(0);
  }

  .header__nav {
    display: none;
  }
}

@media screen and (max-width: 768px) {
  .header__inner {
    gap: 0;
  }

  .header-menu {
    width: 70px;
    padding-right: 10px;
  }

  /* header-logo */
  .header-logo {
    padding-left: 28px;
  }
}

@media screen and (max-width: 480px) {

  /* header-logo */
  .header-logo {
    padding-left: 24px;
  }

  .header-logo img {
    height: 46px;
  }

  /* header__btn__global */
  .header__btn__global svg {
    width: 20px;
  }

  .header__btn__global span {
    display: none;
  }

  .header__btn__global__box {
    top: -20px;
  }

  .header__btn__global__expand {
    min-width: 26px;
  }

  .header__btn__global__expand .img {
    width: 20px;
    height: 20px;
  }
}

/* ============================================================
 * Footer Layout
 * ============================================================ */
#goTop {
  position: absolute;
  right: 50px;
  top: -70px;
  background-color: #002a71;
  width: 50px;
  height: 50px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  padding-top: 4px;
  font-size: .9rem;
  cursor: pointer;
}

#goTop span {
  display: block;
  width: 8px;
  height: 8px;
  border-top: 2px solid #fff;
  border-right: 2px solid #fff;
  transform: rotate(-45deg);
}

.footer {
  color: #ffffff;
  background-color: #1a1a1a;
  padding: 70px 0 100px;
}

.footer .inner-slim {
  position: relative;
}

.footer-logo {
  padding-bottom: 24px;
  border-bottom: 1px solid #fff;
}

.footer-logo img {
  height: 26px;
}

.footer-list {
  display: flex;
  gap: 50px;
  padding: 30px 0;
  border-bottom: 1px solid #fff;
}

.footer-list li {
  display: flex;
  flex-direction: column;
}

.footer-list li a {
  display: inline-block;
  font-size: .875rem;
  font-weight: 300;
  margin-bottom: 6px;
}

.footer-list .menu {
  font-size: 1rem;
  font-weight: 700;
  margin-bottom: 10px;
}

.footer-list .logo {
  margin-left: auto;
  opacity: 0.5;
}

.footer-list .logo img {
  height: 20px;
}

.footer-end {
  padding-top: 30px;
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.footer-info {
  font-size: 0.9rem;
  color: #fff;
  opacity: 0.7;
}

.footer-connect {
  display: flex;
  gap: 50px;
  margin-bottom: 4px;
}

.footer-link {
  position: relative;
  width: 200px;
  font-size: .9rem;
  font-weight: 600;
}

.footer-group {
  width: 100%;
  padding: 14px 20px;
  background-color: rgba(255, 255, 255, .1);
  position: relative;
  cursor: pointer;
}

.footer-group::after {
  content: '';
  position: absolute;
  right: 16px;
  top: 50%;
  width: 10px;
  height: 10px;
  border-right: 1px solid #fff;
  border-bottom: 1px solid #fff;
  /* 닫힘: 아래 화살표(∨). translateY 로 회전 무게중심 보정 */
  transform: translateY(-75%) rotate(45deg);
  transition: transform 0.3s ease;
}

.footer-group.open::after {
  /* 열림: 위 화살표(∧) */
  transform: translateY(-25%) rotate(225deg);
}

.footer-linkbox {
  position: absolute;
  bottom: 100%;
  width: 100%;
  max-height: 0;
  overflow: hidden;
  transition: max-height .7s ease;
}

.footer-linkbox a {
  display: block;
  padding: 14px 20px;
  background-color: rgba(255, 255, 255, .2);
  transition: background-color .3s;
}

.footer-linkbox a:hover {
  background-color: rgba(255, 255, 255, .4);
}

.footer-group.open ~ .footer-linkbox {
  max-height: 300px;
}

/* 영문 푸터 : 메뉴명·주소가 길어 컬럼 간격과 줄바꿈을 따로 조정 */
.footer.en .footer-list {
  gap: 30px;
  align-items: flex-start;
}

/* 균등 분할 대신 글자 길이만큼만 차지하도록 (짧은 컬럼이 벌어지지 않게) */
.footer.en .footer-list li:not(.logo) {
  flex: 0 0 auto;
}

/* 주소가 길어 첫 줄을 통째로 사용 */
.footer.en .footer-connect {
  flex-wrap: wrap;
  gap: 4px 40px;
  margin-bottom: 8px;
}

.footer.en .footer-connect li:first-child {
  flex: 0 0 100%;
}

.footer.en .footer-end {
  align-items: flex-end;
}

@media screen and (max-width: 1280px) {
  .footer.en .footer-list {
    gap: 20px;
  }
}

@media screen and (max-width: 1024px) {
  .footer.en .footer-list {
    flex-wrap: wrap;
    gap: 30px;
  }

  .footer.en .footer-list .logo {
    flex: 0 0 100%;
    margin-left: 0;
  }
}

@media screen and (max-width: 768px) {
  .footer.en .footer-end {
    flex-direction: column;
    align-items: flex-start;
    gap: 24px;
  }
}